@@ -14,6 +14,8 @@ def resample_df(
         aggregation_methods: Optional[Dict[str, str]] = None,
         **kwargs: Any
 ) -> pd.DataFrame:
+    df = df.copy()
+    df[timestamp_col] = pd.to_datetime(df[timestamp_col])
     if aggregation_methods is None:
         aggregation: Union[str, Dict[str, str]] = default_aggregation_method
     else:
